@@ -18,8 +18,6 @@ def red():
   return RED
 def green():
   return GREEN
-def ysn():
-  print("[y/n]", end = "")
 def yellow():
   return YELLOW
 def blue():
@@ -107,3 +105,76 @@ class color():
           sys.stdout.flush()
       else:
         print(f'Error: unknown text formatting: {color}')
+def ysn():
+  print("[y/n]", end = "")
+class math():
+  def add(num1, num2):
+    try:
+      float(num1)
+      float(num2)
+      try:
+        total = float(num1) + float(num2)
+        int(total)
+        print(int(total))
+      except:
+        try:
+          total = float(num1) + float(num2)
+          float(total)
+          print(float(total))
+        except:
+          print("ERROR")
+    except:
+      print("ERROR")
+  def subtract(num1, num2):
+    try:
+      float(num1)
+      float(num2)
+      try:
+        total = float(num1) - float(num2)
+        int(total)
+        print(int(total))
+      except:
+        try:
+          total = float(num1) - float(num2)
+          float(total)
+          print(float(total))
+        except:
+          print("ERROR")
+    except:
+      print("ERROR")
+  def multiply(num1, num2):
+    try:
+      float(num1)
+      float(num2)
+      try:
+        total = float(num1) * float(num2)
+        int(total)
+        print(int(total))
+      except:
+        try:
+          total = float(num1) * float(num2)
+          float(total)
+          print(float(total))
+        except:
+          print("ERROR")
+    except:
+      print("ERROR")
+  def divide(num1, num2):
+    try:
+      float(num1)
+      float(num2)
+      try:
+        total = float(num1) / float(num2)
+        int(total)
+        print(int(total))
+      except:
+        try:
+          total = float(num1) / float(num2)
+          float(total)
+          print(float(total))
+        except:
+          print("ERROR")
+    except:
+      print("ERROR")
+  
+  
